@@ -13,7 +13,11 @@ coerce Amount,
 
 coerce Amount,
     from Str,
-    via { Math::BigFloat->new($_) };
+    via {
+        # strip out formatting characters
+        $_ =~ tr/-()0-9.//cd;
+        Math::BigFloat->new($_)
+    };
 
 
 subtype CurrencyCode,
@@ -24,4 +28,4 @@ subtype CurrencyCode,
 enum Format,
     ( qw(FMT_COMMON FMT_HTML FMT_NAME FMT_STANDARD FMT_SYMBOL) );
 
-1;
\ No newline at end of file
+1;
